emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] master a59f4bb: ; Spelling fixes


From: Paul Eggert
Subject: [Emacs-diffs] master a59f4bb: ; Spelling fixes
Date: Fri, 4 Nov 2016 22:07:17 +0000 (UTC)

branch: master
commit a59f4bb5b8f1e702901d166ce44c4dcddc262b62
Author: Paul Eggert <address@hidden>
Commit: Paul Eggert <address@hidden>

    ; Spelling fixes
---
 doc/misc/tramp.texi          |    2 +-
 etc/NEWS                     |   13 +++++++------
 lisp/registry.el             |   10 +++++-----
 test/lisp/thingatpt-tests.el |    2 +-
 4 files changed, 14 insertions(+), 13 deletions(-)

diff --git a/doc/misc/tramp.texi b/doc/misc/tramp.texi
index d8a2bea..0e09cf7 100644
--- a/doc/misc/tramp.texi
+++ b/doc/misc/tramp.texi
@@ -2459,7 +2459,7 @@ local @file{.emacs} file:
 
 Setting the @env{ENV} environment variable instructs some shells to
 read an initialization file.  Per default, @value{tramp} has disabled
-this.  You could overwrite this behaviour by evaluating
+this.  You could overwrite this behavior by evaluating
 
 @lisp
 @group
diff --git a/etc/NEWS b/etc/NEWS
index f34ee2d..4bf5332 100644
--- a/etc/NEWS
+++ b/etc/NEWS
@@ -87,7 +87,7 @@ the output buffer is not erased; this variable also controls 
where
 to set the point in the output buffer: beginning of the output,
 end of the buffer or save the point.
 When 'shell-command-dont-erase-buffer' is nil, the default value,
-the behaviour of 'shell-command', 'shell-command-on-region' and
+the behavior of 'shell-command', 'shell-command-on-region' and
 'async-shell-command' is as usual.
 
 +++
@@ -234,7 +234,7 @@ all call stack frames in a Lisp backtrace buffer as lists.  
Both
 debug.el and edebug.el have been updated to heed to this variable.
 
 +++
-** The new variable `x-ctrl-keysym` has been added to the existing
+** The new variable 'x-ctrl-keysym' has been added to the existing
 roster of X keysyms.  It can be used in combination with another
 variable of this kind to swap modifiers in Emacs.
 
@@ -372,7 +372,7 @@ also available in 'image-mode'.
 
 +++
 *** A new library for creating and manipulating SVG images has been
-added.  See the "SVG Images" section in the lispref manual for
+added.  See the "SVG Images" section in the Lisp reference manual for
 details.
 
 +++
@@ -543,9 +543,10 @@ function 'check-declare-errmsg' has been removed.
 ** New function 'undo-amalgamate-change-group' to get rid of
 undo-boundaries between two states.
 
-** New var 'definition-prefixes' is a hashtable mapping prefixes to the
-files where corresponding definitions can be found.  This can be used
-to fetch definitions that are not yet loaded, for example for 'C-h f'.
+** New var 'definition-prefixes' is a hash table mapping prefixes to
+the files where corresponding definitions can be found.  This can be
+used to fetch definitions that are not yet loaded, for example for
+'C-h f'.
 
 ** New var 'syntax-ppss-table' to control the syntax-table used in
 'syntax-ppss'.
diff --git a/test/lisp/thingatpt-tests.el b/test/lisp/thingatpt-tests.el
index 9d72db4..6d73d90 100644
--- a/test/lisp/thingatpt-tests.el
+++ b/test/lisp/thingatpt-tests.el
@@ -84,7 +84,7 @@ position to retrieve THING.")
       (goto-char (nth 1 test))
       (should (equal (thing-at-point (nth 2 test)) (nth 3 test))))))
 
-;; These tests reflect the actual behaviour of
+;; These tests reflect the actual behavior of
 ;; `thing-at-point-bounds-of-list-at-point'.
 (ert-deftest thing-at-point-bug24627 ()
   "Test for http://debbugs.gnu.org/24627 ."



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/lisp/registry.el b/lisp/registry.el
index e8bc6f5..3aaa8e8 100644
--- a/lisp/registry.el
+++ b/lisp/registry.el
@@ -35,11 +35,11 @@
 
 ;; tracked: a list of symbols
 
 ;; tracker: a hashtable tuned for 100 symbols to track (you should
 ;; only access this with the :lookup2-function and the
 ;; :lookup2+-function)
 
 ;; data: a hashtable with default size 10K and resize threshold 2.0
 ;; (this reflects the expected usage so override it if you know better)
 
 ;; ...plus methods to do all the work: `registry-search',
@@ -124,10 +124,10 @@
              :documentation "The precious fields, a list of symbols.")
    (tracker :initarg :tracker
             :type hash-table
-            :documentation "The field tracking hashtable.")
+            :documentation "The field tracking hash table.")
    (data :initarg :data
          :type hash-table
-         :documentation "The data hashtable.")))
+         :documentation "The data hash table.")))
 
 (cl-defmethod initialize-instance :before ((this registry-db) slots)
   "Check whether a registry object needs to be upgraded."
@@ -178,7 +178,7 @@ Returns an alist of the key followed by the entry in a 
list, not a cons cell."
 (cl-defmethod registry-lookup-secondary ((db registry-db) tracksym
                                         &optional create)
   "Search for TRACKSYM in the registry-db THIS.
-When CREATE is not nil, create the secondary index hashtable if needed."
+When CREATE is not nil, create the secondary index hash table if needed."
   (let ((h (gethash tracksym (oref db tracker))))
     (if h
        h
@@ -35,11 +35,11 @@
 ;; tracked: a list of symbols
 
-;; tracker: a hashtable tuned for 100 symbols to track (you should
+;; tracker: a hash table tuned for 100 symbols to track (you should
 ;; only access this with the :lookup2-function and the
 ;; :lookup2+-function)
@@ -35,11 +35,11 @@
 ;; :lookup2+-function)
 
-;; data: a hashtable with default size 10K and resize threshold 2.0
+;; data: a hash table with default size 10K and resize threshold 2.0
 ;; (this reflects the expected usage so override it if you know better)
 